@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::TABULO;
 ### ex: set ft=perl noai ts=4 sw=4:
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000006';
 
 use 5.026; # Indented HEREDOC.
 use Data::Printer qw(p np);
@@ -356,10 +356,23 @@ has pod_coverage_also_private => (
 
 has tag_format => (
     isa     => 'Str',
-    default => 'release-%v',
-    -doc    =>
-      "The tag format passed to [Git::Tag]. The default is 'release-%v', copied from \@DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex. ",
-      );
+    default => 'repo-release-v%V%t',
+    -doc    => <<~"__EOT__"
+The tag format passed to [Git::Tag] after committing sources.
+The default is 'repo-release-v%V%t', which may be prefixed by some other string.
+The idea was copied from \@DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex.
+__EOT__
+    );
+
+has tag_format_dist => (
+    isa     => 'Str',
+    default => 'dist-release-v%V%t',
+    -doc    => <<~"__EOT__"
+The tag format passed to [Git::Tag] after committing the build.
+The default is 'dist-release-v%V%t', which may be prefixed by some other string.
+The idea was copied from \@DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex.
+__EOT__
+    );
 
 has stopwords => ( ## ALIAS: stopword
     isa     => 'ArrayRef',
@@ -387,7 +400,7 @@ __EOT__
 
 has version_regexp => (
     isa     => 'Str',
-    default => '^release-(.+)$',
+    default => '^(?:[-\w]+)?release-(.+)$',
     -doc    => "The version regex that corresponds to the 'tag_format'.",
     );
 
@@ -697,7 +710,7 @@ sub _plug__GitCommitBuild__toReleaseBranch {
 
     (
     ["Git::CommitBuild/$label" => { branch => '', release_branch => $branch,  multiple_inheritence => 1 } ],
-    ["Git::Tag/$label"  => { branch => $branch, tag_format => $self->tag_format . "/CPAN)" } ],
+    ["Git::Tag/$label"  => { branch => $branch, tag_format => $self->tag_format_dist } ],
     )
 }
 
@@ -939,7 +952,7 @@ Dist::Zilla::PluginBundle::Author::TABULO - A Dist::Zilla plugin bundle à la TA
 
 =head1 VERSION
 
-version 1.000004
+version 1.000006
 
 =head1 SYNOPSIS
 
@@ -1623,7 +1636,21 @@ Reader: tag_format
 
 Type: Str
 
-Additional documentation: The tag format passed to [Git::Tag]. The default is 'release-%v', copied from @DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex.  Default: 'release-%v'
+Additional documentation: The tag format passed to [Git::Tag] after committing sources.
+The default is 'repo-release-v%V%t', which may be prefixed by some other string.
+The idea was copied from @DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex.
+ Default: 'repo-release-v%V%t'
+
+=head2 tag_format_dist
+
+Reader: tag_format_dist
+
+Type: Str
+
+Additional documentation: The tag format passed to [Git::Tag] after committing the build.
+The default is 'dist-release-v%V%t', which may be prefixed by some other string.
+The idea was copied from @DAGOLDEN who chose something more robust than just the version number when parsing versions with a regex.
+ Default: 'dist-release-v%V%t'
 
 =head2 version_regexp
 
@@ -1631,7 +1658,7 @@ Reader: version_regexp
 
 Type: Str
 
-Additional documentation: The version regex that corresponds to the 'tag_format'. Default: '^release-(.+)$'
+Additional documentation: The version regex that corresponds to the 'tag_format'. Default: '^(?:[-\w]+)?release-(.+)$'
 
 =head2 weaver_config
 
